@@ -41,7 +41,7 @@ def process_micro_batch(micro_batch_output_df, batchId, merge_sql_stmt, unique_i
     """
     if len(unique_id_list) > 0:
         micro_batch_output_df = micro_batch_output_df.dropDuplicates(unique_id_list)
-    micro_batch_output_df = micro_batch_output_df.withColumn("filename", F.input_file_name())
+    #micro_batch_output_df = micro_batch_output_df.withColumn("filename", F.input_file_name())
     upsert_to_delta_with_sql(micro_batch_output_df, batchId, merge_sql_stmt)
 
 
